@@ -204,6 +204,21 @@ class ConfigEntryTest(TestCase):
         self.assertEqual(dict(nd), dict(**nd))
         self.assertEqual(dict(nd), d)
 
+    def test_setOfMappings(self):
+
+        data = {'a': [ {'b': {'c': 'c'} }, {'e': 'f:' }]}
+
+        nd = NestedDict(data)
+
+        i = iter(nd.a)
+
+        a = i.next()
+        self.assertEqual(a.b.c, 'c')
+
+        a = i.next()
+        self.assertEqual(a.e, 'f')
+
+
 
 def test_suite():
     from unittest import TestLoader
